package com.lottery.customer.controller;

import com.lottery.customer.entity.TaCustomerBill;
import com.lottery.customer.service.TaCustomerBillService;
import com.lottery.customer.vo.TaCustomerBillVo;
import lombok.extern.slf4j.Slf4j;
import com.lottery.customer.param.TaCustomerBillPageParam;
import io.geekidea.springbootplus.framework.common.controller.BaseController;
import io.geekidea.springbootplus.framework.common.api.ApiResult;
import io.geekidea.springbootplus.framework.core.pagination.Paging;
import io.geekidea.springbootplus.framework.common.param.IdParam;
import io.geekidea.springbootplus.framework.log.annotation.Module;
import io.geekidea.springbootplus.framework.log.annotation.OperationLog;
import io.geekidea.springbootplus.framework.log.enums.OperationLogType;
import io.geekidea.springbootplus.framework.core.validator.groups.Add;
import io.geekidea.springbootplus.framework.core.validator.groups.Update;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 客户账单流水 控制器
 *
 * @author fxf
 * @since 2020-09-08
 */
@Slf4j
@RestController
@RequestMapping("/taCustomerBill")
@Module("customer")
@Api(value = "客户账单流水API", tags = {"客户账单流水"})
public class TaCustomerBillController extends BaseController {

    @Autowired
    private TaCustomerBillService taCustomerBillService;

    /**
     * 添加客户账单流水
     */
    @PostMapping("/add")
    @OperationLog(name = "添加客户账单流水", type = OperationLogType.ADD)
    @ApiOperation(value = "添加客户账单流水", response = ApiResult.class)
    public ApiResult<Boolean> addTaCustomerBill(@Validated(Add.class) @RequestBody TaCustomerBill taCustomerBill) throws Exception {
        boolean flag = taCustomerBillService.saveTaCustomerBill(taCustomerBill);
        return ApiResult.result(flag);
    }

    /**
     * 修改客户账单流水
     */
    @PostMapping("/update")
    @OperationLog(name = "修改客户账单流水", type = OperationLogType.UPDATE)
    @ApiOperation(value = "修改客户账单流水", response = ApiResult.class)
    public ApiResult<Boolean> updateTaCustomerBill(@Validated(Update.class) @RequestBody TaCustomerBill taCustomerBill) throws Exception {
        boolean flag = taCustomerBillService.updateTaCustomerBill(taCustomerBill);
        return ApiResult.result(flag);
    }

    /**
     * 删除客户账单流水
     */
    @PostMapping("/delete/{id}")
    @OperationLog(name = "删除客户账单流水", type = OperationLogType.DELETE)
    @ApiOperation(value = "删除客户账单流水", response = ApiResult.class)
    public ApiResult<Boolean> deleteTaCustomerBill(@PathVariable("id") Long id) throws Exception {
        boolean flag = taCustomerBillService.deleteTaCustomerBill(id);
        return ApiResult.result(flag);
    }

    /**
     * 获取客户账单流水详情
     */
    @GetMapping("/info/{id}")
    @OperationLog(name = "客户账单流水详情", type = OperationLogType.INFO)
    @ApiOperation(value = "客户账单流水详情", response = TaCustomerBill.class)
    public ApiResult<TaCustomerBill> getTaCustomerBill(@PathVariable("id") Long id) throws Exception {
        TaCustomerBill taCustomerBill = taCustomerBillService.getById(id);
        return ApiResult.ok(taCustomerBill);
    }

    /**
     * 客户账单流水分页列表
     */
    @PostMapping("/getPageList")
    @OperationLog(name = "客户账单流水分页列表", type = OperationLogType.PAGE)
    @ApiOperation(value = "客户账单流水分页列表", response = TaCustomerBill.class)
    public ApiResult<Paging<TaCustomerBillVo>> getTaCustomerBillPageList(@Validated @RequestBody TaCustomerBillPageParam taCustomerBillPageParam) throws Exception {
        Paging<TaCustomerBillVo> paging = taCustomerBillService.getTaCustomerBillPageList(taCustomerBillPageParam);
        return ApiResult.ok(paging);
    }

}

