package com.lottery.customer.controller;

import com.lottery.customer.entity.TaCustomer;
import com.lottery.customer.service.TaCustomerService;
import com.lottery.customer.vo.TaCustomerVo;
import lombok.extern.slf4j.Slf4j;
import com.lottery.customer.param.TaCustomerPageParam;
import io.geekidea.springbootplus.framework.common.controller.BaseController;
import io.geekidea.springbootplus.framework.common.api.ApiResult;
import io.geekidea.springbootplus.framework.core.pagination.Paging;
import io.geekidea.springbootplus.framework.common.param.IdParam;
import io.geekidea.springbootplus.framework.log.annotation.Module;
import io.geekidea.springbootplus.framework.log.annotation.OperationLog;
import io.geekidea.springbootplus.framework.log.enums.OperationLogType;
import io.geekidea.springbootplus.framework.core.validator.groups.Add;
import io.geekidea.springbootplus.framework.core.validator.groups.Update;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 客户 控制器
 *
 * @author fxf
 * @since 2020-09-08
 */
@Slf4j
@RestController
@RequestMapping("/taCustomer")
@Module("customer")
@Api(value = "客户API", tags = {"客户"})
public class TaCustomerController extends BaseController {

    @Autowired
    private TaCustomerService taCustomerService;

    /**
     * 添加客户
     */
    @PostMapping("/add")
    @OperationLog(name = "添加客户", type = OperationLogType.ADD)
    @ApiOperation(value = "添加客户", response = ApiResult.class)
    public ApiResult<Boolean> addTaCustomer(@Validated(Add.class) @RequestBody TaCustomer taCustomer) throws Exception {
        boolean flag = taCustomerService.saveTaCustomer(taCustomer);
        return ApiResult.result(flag);
    }

    /**
     * 修改客户
     */
    @PostMapping("/update")
    @OperationLog(name = "修改客户", type = OperationLogType.UPDATE)
    @ApiOperation(value = "修改客户", response = ApiResult.class)
    public ApiResult<Boolean> updateTaCustomer(@Validated(Update.class) @RequestBody TaCustomer taCustomer) throws Exception {
        boolean flag = taCustomerService.updateTaCustomer(taCustomer);
        return ApiResult.result(flag);
    }

    /**
     * 删除客户
     */
    @PostMapping("/delete/{id}")
    @OperationLog(name = "删除客户", type = OperationLogType.DELETE)
    @ApiOperation(value = "删除客户", response = ApiResult.class)
    public ApiResult<Boolean> deleteTaCustomer(@PathVariable("id") Long id) throws Exception {
        boolean flag = taCustomerService.deleteTaCustomer(id);
        return ApiResult.result(flag);
    }

    /**
     * 获取客户详情
     */
    @GetMapping("/info/{id}")
    @OperationLog(name = "客户详情", type = OperationLogType.INFO)
    @ApiOperation(value = "客户详情", response = TaCustomer.class)
    public ApiResult<TaCustomer> getTaCustomer(@PathVariable("id") Long id) throws Exception {
        TaCustomer taCustomer = taCustomerService.getById(id);
        return ApiResult.ok(taCustomer);
    }

    /**
     * 客户分页列表
     */
    @PostMapping("/getPageList")
    @OperationLog(name = "客户分页列表", type = OperationLogType.PAGE)
    @ApiOperation(value = "客户分页列表", response = TaCustomer.class)
    public ApiResult<Paging<TaCustomerVo>> getTaCustomerPageList(@Validated @RequestBody TaCustomerPageParam taCustomerPageParam) throws Exception {
        Paging<TaCustomerVo> paging = taCustomerService.getTaCustomerPageList(taCustomerPageParam);
        return ApiResult.ok(paging);
    }

}

